/*
 * signal.h - define macros and functions for signal handling
 *
 * Copyright (c) 1990 HiSoft
 */
 
#ifndef _SIGNAL_H
#define _SIGNAL_H

/*
 *
 * This header file contains definitions needed by the signal function.
 *
 */

/*
 *
 * NSIG supposedly defines the number of signals recognized.  However,
 * since not all signals are actually implemented under GEMDOS, it actually
 * is the highest legal signal number plus one.
 *
 */

#define NSIG     9
#define SIG_MAX  8
			
/**
*
* The following symbols are the defined signals.
*
*/

#define SIGABRT  1      /*  Abnormal termination, abort()  */
#define SIGFPE   2      /*  Floating point exception  */
#define SIGILL   3      /*  Illegal instruction  */
#define SIGINT   4      /*  Interrupt from GEMDOS */
#define SIGSEGV  5      /*  Segmentation violation  */
#define SIGTERM  6      /*  Termination request  */

/*
 *
 * The following symbols are the special forms for the function pointer
 * argument.  They specify certain standard actions that can be performed
 * when the signal occurs.
 *
 */

#define SIG_DFL (void (*)(int)) 0	/* default action */
#define SIG_IGN (void (*)(int)) 1	/* ignore the signal */
#define SIG_ERR (void (*)(int)) (-1)	/* error return */

/*
 *
 * Function declarations
 *
 */

extern void (*signal(int,void (*)(int)))(int);
extern int raise(int);

extern void (*__sigfunc[NSIG])(int);

typedef long sig_atomic_t;
#endif
